@@ -24,12 +24,15 @@ from je_auto_control.utils.file_process.create_project_structure import create_t
 # file process
 from je_auto_control.utils.file_process.get_dir_file_list import get_dir_files_as_list
 # html report
-from je_auto_control.utils.html_report.html_report_generate import generate_html
+from je_auto_control.utils.generate_report.generate_html_report import generate_html
+from je_auto_control.utils.generate_report.generate_html_report import generate_html_report
 # utils image
 from je_auto_control.utils.image.screenshot import pil_screenshot
 # json
 from je_auto_control.utils.json.json_file import read_action_json
 from je_auto_control.utils.json.json_file import write_action_json
+from je_auto_control.utils.generate_report.generate_json_report import generate_json
+from je_auto_control.utils.generate_report.generate_json_report import generate_json_report
 # socket server
 from je_auto_control.utils.socket_server.auto_control_socket_server import start_autocontrol_socket_server
 # test record
@@ -63,6 +66,11 @@ from je_auto_control.wrapper.auto_control_record import stop_record
 from je_auto_control.wrapper.auto_control_screen import screenshot
 # import screen
 from je_auto_control.wrapper.auto_control_screen import size
+# xml
+from je_auto_control.utils.generate_report.generate_xml_report import generate_xml
+from je_auto_control.utils.generate_report.generate_xml_report import generate_xml_report
+# callback
+from je_auto_control.utils.callback.callback_function_executor import callback_executor
 
 __all__ = [
     "click_mouse", "mouse_table", "position", "press_mouse", "release_mouse",
@@ -83,6 +91,9 @@ __all__ = [
     "multiprocess_timeout", "test_record_instance",
     "screenshot",
     "pil_screenshot",
-    "generate_html",
-    "get_dir_files_as_list", "create_template_dir", "start_autocontrol_socket_server"
+    "generate_html", "generate_html_report",
+    "generate_json", "generate_json_report",
+    "generate_xml", "generate_xml_report",
+    "get_dir_files_as_list", "create_template_dir", "start_autocontrol_socket_server",
+    "callback_executor"
 ]
