@@ -1,6 +1,6 @@
-#!C:\Users\JeffreyChen\Desktop\Code_Space\Python\ITE\AutoControl\venv\Scripts\python.exe
+#!C:\Users\JeffreyChen\Desktop\Code_Space\AutoControl\venv\Scripts\python.exe
 
-# $Id: rst2odt.py 5839 2009-01-07 19:09:28Z dkuhlman $
+# $Id: rst2odt.py 8994 2022-01-29 16:28:17Z milde $
 # Author: Dave Kuhlman <dkuhlman@rexx.com>
 # Copyright: This module has been placed in the public domain.
 
@@ -8,7 +8,6 @@
 A front end to the Docutils Publisher, producing OpenOffice documents.
 """
 
-import sys
 try:
     import locale
     locale.setlocale(locale.LC_ALL, '')
@@ -26,5 +25,4 @@ description = ('Generates OpenDocument/OpenOffice/ODF documents from '
 writer = Writer()
 reader = Reader()
 output = publish_cmdline_to_binary(reader=reader, writer=writer,
-    description=description)
-
+                                   description=description)
